## Typing stubs for ibm-db

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`ibm-db`](https://github.com/ibmdb/python-ibmdb) package. It can be used by type checkers
to check code that uses `ibm-db`. This version of
`types-ibm-db` aims to provide accurate annotations for
`ibm-db==3.2.8`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/ibm-db`](https://github.com/python/typeshed/tree/main/stubs/ibm-db)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.19.1
* [pyright](https://github.com/microsoft/pyright) 1.1.408

It was generated from typeshed commit
[`fdbb8d5e343a36045d28caeae255c87c45da1946`](https://github.com/python/typeshed/commit/fdbb8d5e343a36045d28caeae255c87c45da1946).